# stglance

`stglance` is a small collection of `streamlit` widgets that you can include in your streamlit app.


## Setting up for development

1. `poetry install`
2. `poetry run pre-commit autoupdate`
